==> pdf-model-arlington-1.25.14-sources.jar: org/verapdf/model/alayer/AAnnotFreeText.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AAnnotFreeText extends AObject {
	














	/**
	*/
	public Boolean getcontainsAF();

	/**
	*/
	public Boolean getAFHasTypeArray();

	/**
	*/
	public Boolean getAFHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsAP();

	/**
	*/
	public Boolean getAPHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsAS();

	/**
	*/
	public Boolean getASHasTypeName();

	/**
	*/
	public Boolean getcontainsBE();

	/**
	*/
	public Boolean getBEHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsBM();

	/**
	*/
	public Boolean getBMHasTypeName();

	/**
	*/
	public String getBMNameValue();

	/**
	*/
	public Boolean getcontainsBS();

	/**
	*/
	public Boolean getBSHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsBorder();

	/**
	*/
	public Boolean getBorderHasTypeArray();

	/**
	*/
	public Boolean getcontainsC();

	/**
	*/
	public Boolean getCHasTypeArray();

	/**
	*/
	public Boolean getcontainsCA();

	/**
	*/
	public Boolean getCAHasTypeNumber();

	/**
	*/
	public Double getCANumberValue();

	/**
	*/
	public Boolean getcontainsCL();

	/**
	*/
	public Boolean getCLHasTypeArray();

	/**
	*/
	public Boolean getcontainsContents();

	/**
	*/
	public Boolean getContentsHasTypeStringText();

	/**
	*/
	public Boolean getcontainsCreationDate();

	/**
	*/
	public Boolean getCreationDateHasTypeDate();

	/**
	*/
	public Boolean getcontainsDA();

	/**
	*/
	public Boolean getDAHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsDS();

	/**
	*/
	public Boolean getDSHasTypeStringText();

	/**
	*/
	public Boolean getcontainsExData();

	/**
	*/
	public Boolean getExDataHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public Boolean getFHasTypeBitmask();

	/**
	*/
	public Long getFBitmaskValue();

	/**
	*/
	public Boolean getcontainsIRT();

	/**
	*/
	public Boolean getIRTHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsIT();

	/**
	*/
	public Boolean getITHasTypeName();

	/**
	*/
	public String getITNameValue();

	/**
	*/
	public Boolean getcontainsLE();

	/**
	*/
	public Boolean getLEHasTypeName();

	/**
	*/
	public String getLENameValue();

	/**
	*/
	public Boolean getcontainsLang();

	/**
	*/
	public Boolean getLangHasTypeStringText();

	/**
	*/
	public Boolean getcontainsM();

	/**
	*/
	public Boolean getMHasTypeDate();

	/**
	*/
	public Boolean getMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsNM();

	/**
	*/
	public Boolean getNMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsOC();

	/**
	*/
	public Boolean getOCHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public Boolean getisPIndirect();

	/**
	*/
	public Boolean getPHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsPopup();

	/**
	*/
	public Boolean getisPopupIndirect();

	/**
	*/
	public Boolean getPopupHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsQ();

	/**
	*/
	public Boolean getQHasTypeInteger();

	/**
	*/
	public Long getQIntegerValue();

	/**
	*/
	public Boolean getcontainsRC();

	/**
	*/
	public Boolean getisRCIndirect();

	/**
	*/
	public Boolean getRCHasTypeStream();

	/**
	*/
	public Boolean getRCHasTypeStringText();

	/**
	*/
	public Boolean getcontainsRD();

	/**
	*/
	public Boolean getRDHasTypeRectangle();

	/**
	*/
	public Boolean getcontainsRT();

	/**
	*/
	public Boolean getRTHasTypeName();

	/**
	*/
	public String getRTNameValue();

	/**
	*/
	public Boolean getcontainsRect();

	/**
	*/
	public Boolean getRectHasTypeRectangle();

	/**
	*/
	public Double getRectRectHeight();

	/**
	*/
	public Double getRectRectWidth();

	/**
	*/
	public Boolean getcontainsStructParent();

	/**
	*/
	public Boolean getStructParentHasTypeInteger();

	/**
	*/
	public Boolean getcontainsSubj();

	/**
	*/
	public Boolean getSubjHasTypeStringText();

	/**
	*/
	public Boolean getcontainsSubtype();

	/**
	*/
	public Boolean getSubtypeHasTypeName();

	/**
	*/
	public String getSubtypeNameValue();

	/**
	*/
	public Boolean getcontainsT();

	/**
	*/
	public Boolean getTHasTypeStringText();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsca();

	/**
	*/
	public Boolean getcaHasTypeNumber();

	/**
	*/
	public Double getcaNumberValue();

	/**
	*/
	public Double getRD2NumberValue();

	/**
	*/
	public Double getRD3NumberValue();

	/**
	*/
	public Double getRD0NumberValue();

	/**
	*/
	public Double getRD1NumberValue();

	/**
	*/
	public Boolean getAPNHasTypeDictionary();

	/**
	*/
	public Boolean getAPRHasTypeDictionary();

	/**
	*/
	public Boolean getAPDHasTypeDictionary();

	/**
	*/
	public Boolean gethasExtensionADBE_Extn3();
}

==> pdf-model-arlington-1.25.28-sources.jar: org/verapdf/model/alayer/AAnnotFreeText.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AAnnotFreeText extends AObject {
	














	/**
	*/
	public Boolean getcontainsAF();

	/**
	*/
	public String getAFType();

	/**
	*/
	public Boolean getAFHasTypeArray();

	/**
	*/
	public Boolean getAFHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsAP();

	/**
	*/
	public String getAPType();

	/**
	*/
	public Boolean getAPHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsAS();

	/**
	*/
	public String getASType();

	/**
	*/
	public Boolean getASHasTypeName();

	/**
	*/
	public Boolean getcontainsBE();

	/**
	*/
	public String getBEType();

	/**
	*/
	public Boolean getBEHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsBM();

	/**
	*/
	public String getBMType();

	/**
	*/
	public Boolean getBMHasTypeName();

	/**
	*/
	public String getBMNameValue();

	/**
	*/
	public Boolean getcontainsBS();

	/**
	*/
	public String getBSType();

	/**
	*/
	public Boolean getBSHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsBorder();

	/**
	*/
	public String getBorderType();

	/**
	*/
	public Boolean getBorderHasTypeArray();

	/**
	*/
	public Boolean getcontainsC();

	/**
	*/
	public String getCType();

	/**
	*/
	public Boolean getCHasTypeArray();

	/**
	*/
	public Boolean getcontainsCA();

	/**
	*/
	public String getCAType();

	/**
	*/
	public Boolean getCAHasTypeNumber();

	/**
	*/
	public Double getCANumberValue();

	/**
	*/
	public Boolean getcontainsCL();

	/**
	*/
	public String getCLType();

	/**
	*/
	public Boolean getCLHasTypeArray();

	/**
	*/
	public Boolean getcontainsContents();

	/**
	*/
	public String getContentsType();

	/**
	*/
	public Boolean getContentsHasTypeStringText();

	/**
	*/
	public Boolean getcontainsCreationDate();

	/**
	*/
	public String getCreationDateType();

	/**
	*/
	public Boolean getCreationDateHasTypeDate();

	/**
	*/
	public Boolean getcontainsDA();

	/**
	*/
	public String getDAType();

	/**
	*/
	public Boolean getDAHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsDS();

	/**
	*/
	public String getDSType();

	/**
	*/
	public Boolean getDSHasTypeStringText();

	/**
	*/
	public Boolean getcontainsExData();

	/**
	*/
	public String getExDataType();

	/**
	*/
	public Boolean getExDataHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public String getFType();

	/**
	*/
	public Boolean getFHasTypeBitmask();

	/**
	*/
	public Long getFBitmaskValue();

	/**
	*/
	public Boolean getcontainsIRT();

	/**
	*/
	public String getIRTType();

	/**
	*/
	public Boolean getIRTHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsIT();

	/**
	*/
	public String getITType();

	/**
	*/
	public Boolean getITHasTypeName();

	/**
	*/
	public String getITNameValue();

	/**
	*/
	public Boolean getcontainsLE();

	/**
	*/
	public String getLEType();

	/**
	*/
	public Boolean getLEHasTypeName();

	/**
	*/
	public String getLENameValue();

	/**
	*/
	public Boolean getcontainsLang();

	/**
	*/
	public String getLangType();

	/**
	*/
	public Boolean getLangHasTypeStringText();

	/**
	*/
	public Boolean getcontainsM();

	/**
	*/
	public String getMType();

	/**
	*/
	public Boolean getMHasTypeDate();

	/**
	*/
	public Boolean getMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsNM();

	/**
	*/
	public String getNMType();

	/**
	*/
	public Boolean getNMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsOC();

	/**
	*/
	public String getOCType();

	/**
	*/
	public Boolean getOCHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public Boolean getisPIndirect();

	/**
	*/
	public String getPType();

	/**
	*/
	public Boolean getPHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsPopup();

	/**
	*/
	public Boolean getisPopupIndirect();

	/**
	*/
	public String getPopupType();

	/**
	*/
	public Boolean getPopupHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsQ();

	/**
	*/
	public String getQType();

	/**
	*/
	public Boolean getQHasTypeInteger();

	/**
	*/
	public Long getQIntegerValue();

	/**
	*/
	public Boolean getcontainsRC();

	/**
	*/
	public Boolean getisRCIndirect();

	/**
	*/
	public String getRCType();

	/**
	*/
	public Boolean getRCHasTypeStream();

	/**
	*/
	public Boolean getRCHasTypeStringText();

	/**
	*/
	public Boolean getcontainsRD();

	/**
	*/
	public String getRDType();

	/**
	*/
	public Boolean getRDHasTypeRectangle();

	/**
	*/
	public Boolean getcontainsRT();

	/**
	*/
	public String getRTType();

	/**
	*/
	public Boolean getRTHasTypeName();

	/**
	*/
	public String getRTNameValue();

	/**
	*/
	public Boolean getcontainsRect();

	/**
	*/
	public String getRectType();

	/**
	*/
	public Boolean getRectHasTypeRectangle();

	/**
	*/
	public Double getRectRectHeight();

	/**
	*/
	public Double getRectRectWidth();

	/**
	*/
	public Boolean getcontainsStructParent();

	/**
	*/
	public String getStructParentType();

	/**
	*/
	public Boolean getStructParentHasTypeInteger();

	/**
	*/
	public Boolean getcontainsSubj();

	/**
	*/
	public String getSubjType();

	/**
	*/
	public Boolean getSubjHasTypeStringText();

	/**
	*/
	public Boolean getcontainsSubtype();

	/**
	*/
	public String getSubtypeType();

	/**
	*/
	public Boolean getSubtypeHasTypeName();

	/**
	*/
	public String getSubtypeNameValue();

	/**
	*/
	public Boolean getcontainsT();

	/**
	*/
	public String getTType();

	/**
	*/
	public Boolean getTHasTypeStringText();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsca();

	/**
	*/
	public String getcaType();

	/**
	*/
	public Boolean getcaHasTypeNumber();

	/**
	*/
	public Double getcaNumberValue();

	/**
	*/
	public Double getRD0NumberValue();

	/**
	*/
	public Double getRD1NumberValue();

	/**
	*/
	public Double getRD2NumberValue();

	/**
	*/
	public Double getRD3NumberValue();

	/**
	*/
	public Boolean getAPDHasTypeDictionary();

	/**
	*/
	public Boolean getAPNHasTypeDictionary();

	/**
	*/
	public Boolean getAPRHasTypeDictionary();

	/**
	*/
	public Boolean gethasExtensionADBE_Extn3();
}
